==> fdowms-3.2.0.tar.gz: OpenSource_FDO/Providers/WMS/Src/Provider/FdoWmsDescribeSchemaMappingCommand.cpp <==
/*
 * Copyright (C) 2004-2006  Autodesk, Inc.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2.1 of the GNU Lesser
 * General Public License as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "stdafx.h"
#include <FdoWmsDescribeSchemaMappingCommand.h>

FdoWmsDescribeSchemaMappingCommand::FdoWmsDescribeSchemaMappingCommand (FdoIConnection * connection)
	: FdoWmsCommand<FdoIDescribeSchemaMapping> (connection)
{
}

void FdoWmsDescribeSchemaMappingCommand::SetSchemaName(FdoString* value)
{
	mSchemaName = value;
}

FdoString* FdoWmsDescribeSchemaMappingCommand::GetSchemaName()
{
	return mSchemaName;
}

void FdoWmsDescribeSchemaMappingCommand::SetIncludeDefaults(FdoBoolean includeDefaults)
{
	mbIncludeDefaults = includeDefaults;
}

FdoBoolean FdoWmsDescribeSchemaMappingCommand::GetIncludeDefaults()
{
	return mbIncludeDefaults;
}


FdoPhysicalSchemaMappingCollection* FdoWmsDescribeSchemaMappingCommand::Execute()
{
	VALIDATE_ARGUMENT (mConnection.p);

	return mConnection->GetSchemaMappings ();
}

void FdoWmsDescribeSchemaMappingCommand::Dispose ()
{
	delete this;
}

FdoWmsDescribeSchemaMappingCommand::~FdoWmsDescribeSchemaMappingCommand ()
{
}

==> fdowms-3.2.2.tar.gz: OpenSource_FDO/Providers/WMS/Src/Provider/FdoWmsDescribeSchemaMappingCommand.cpp <==
/*
 * Copyright (C) 2004-2006  Autodesk, Inc.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2.1 of the GNU Lesser
 * General Public License as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "stdafx.h"
#include <FdoWmsDescribeSchemaMappingCommand.h>

FdoWmsDescribeSchemaMappingCommand::FdoWmsDescribeSchemaMappingCommand (FdoIConnection * connection)
	: FdoWmsCommand<FdoIDescribeSchemaMapping> (connection)
{
}

void FdoWmsDescribeSchemaMappingCommand::SetSchemaName(FdoString* value)
{
	mSchemaName = value;
}

FdoString* FdoWmsDescribeSchemaMappingCommand::GetSchemaName()
{
	return mSchemaName;
}

void FdoWmsDescribeSchemaMappingCommand::SetIncludeDefaults(FdoBoolean includeDefaults)
{
	mbIncludeDefaults = includeDefaults;
}

FdoBoolean FdoWmsDescribeSchemaMappingCommand::GetIncludeDefaults()
{
	return mbIncludeDefaults;
}


FdoPhysicalSchemaMappingCollection* FdoWmsDescribeSchemaMappingCommand::Execute()
{
	VALIDATE_ARGUMENT (mConnection.p);

	return mConnection->GetSchemaMappings (mbIncludeDefaults);
}

void FdoWmsDescribeSchemaMappingCommand::Dispose ()
{
	delete this;
}

FdoWmsDescribeSchemaMappingCommand::~FdoWmsDescribeSchemaMappingCommand ()
{
}
